pub struct CommandBufferRef(/* private fields */);Expand description
A borrowed reference to a CommandBuffer.
Implementations
Sourceimpl CommandBufferRef
impl CommandBufferRef
pub fn label(&self) -> &str
pub fn set_label(&self, label: &str)
pub fn enqueue(&self)
pub fn commit(&self)
pub fn status(&self) -> MTLCommandBufferStatus
pub fn present_drawable(&self, drawable: &DrawableRef)
pub fn wait_until_completed(&self)
pub fn wait_until_scheduled(&self)
pub fn add_completed_handler(&self, block: &Block<(&'_ CommandBufferRef,), ()>)
pub fn add_scheduled_handler(&self, block: &Block<(&'_ CommandBufferRef,), ()>)
Sourcepub fn new_blit_command_encoder(&self) -> &BlitCommandEncoderRef
pub fn new_blit_command_encoder(&self) -> &BlitCommandEncoderRef
Create a blit command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.
pub fn blit_command_encoder_with_descriptor( &self, descriptor: &BlitPassDescriptorRef, ) -> &BlitCommandEncoderRef
Sourcepub fn new_compute_command_encoder(&self) -> &ComputeCommandEncoderRef
pub fn new_compute_command_encoder(&self) -> &ComputeCommandEncoderRef
Create a compute command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.
pub fn compute_command_encoder_with_dispatch_type( &self, ty: MTLDispatchType, ) -> &ComputeCommandEncoderRef
pub fn compute_command_encoder_with_descriptor( &self, descriptor: &ComputePassDescriptorRef, ) -> &ComputeCommandEncoderRef
Sourcepub fn new_render_command_encoder(
&self,
descriptor: &RenderPassDescriptorRef,
) -> &RenderCommandEncoderRef
pub fn new_render_command_encoder( &self, descriptor: &RenderPassDescriptorRef, ) -> &RenderCommandEncoderRef
Create a render command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.
Sourcepub fn new_parallel_render_command_encoder(
&self,
descriptor: &RenderPassDescriptorRef,
) -> &ParallelRenderCommandEncoderRef
pub fn new_parallel_render_command_encoder( &self, descriptor: &RenderPassDescriptorRef, ) -> &ParallelRenderCommandEncoderRef
Create a parallel render command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.
Sourcepub fn new_acceleration_structure_command_encoder(
&self,
) -> &AccelerationStructureCommandEncoderRef
pub fn new_acceleration_structure_command_encoder( &self, ) -> &AccelerationStructureCommandEncoderRef
Create an acceleration structure command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.
Sourcepub fn acceleration_structure_command_encoder_with_descriptor(
&self,
descriptor: &AccelerationStructurePassDescriptorRef,
) -> &AccelerationStructureCommandEncoderRef
pub fn acceleration_structure_command_encoder_with_descriptor( &self, descriptor: &AccelerationStructurePassDescriptorRef, ) -> &AccelerationStructureCommandEncoderRef
Create an acceleration structure command encoder.
Although this method is named with a new_ prefix, the actual Metal
method is not, and it returns an object that has been added to the
autorelease pool. See https://github.com/gfx-rs/metal-rs/issues/128.